@@ -2,7 +2,7 @@
 from .env_settings import BaseSettings
 from .exceptions import *
 from .fields import Required
-from .main import BaseModel, validator
+from .main import BaseConfig, BaseModel, create_model, validator
 from .parse import Protocol
 from .types import *
 from .version import VERSION
