@@ -1,8 +1,9 @@
 import warnings
-from collections import OrderedDict
+from abc import ABCMeta
+from copy import deepcopy
 from pathlib import Path
 from types import FunctionType
-from typing import Any, Dict, Set, Union
+from typing import Any, Dict, Set, Type, Union
 
 from .exceptions import ConfigError, Error, Extra, Missing, ValidationError
 from .fields import Field, Validator
@@ -21,6 +22,7 @@ class BaseConfig:
     ignore_extra = True
     allow_extra = False
     allow_mutation = True
+    use_enum_values = False
     fields = {}
     validate_assignment = False
 
@@ -51,18 +53,22 @@ def _extract_validators(namespace):
     return validators
 
 
-class MetaModel(type):
-    @classmethod
-    def __prepare__(mcs, *args, **kwargs):
-        return OrderedDict()
+def _get_validators(validators, name):
+    specific_validators = validators.get(name)
+    wildcard_validators = validators.get('*')
+    if specific_validators or wildcard_validators:
+        return (specific_validators or []) + (wildcard_validators or [])
+
+
+class MetaModel(ABCMeta):
 
     def __new__(mcs, name, bases, namespace):
-        fields = OrderedDict()
+        fields = {}
         config = BaseConfig
         for base in reversed(bases):
             if issubclass(base, BaseModel) and base != BaseModel:
                 fields.update(base.__fields__)
-                config = inherit_config(base.config, config)
+                config = inherit_config(base.__config__, config)
 
         config = inherit_config(namespace.get('Config'), config)
         validators = _extract_validators(namespace)
@@ -78,7 +84,7 @@ class MetaModel(type):
                     name=ann_name,
                     value=...,
                     annotation=ann_type,
-                    class_validators=validators.get(ann_name),
+                    class_validators=_get_validators(validators, ann_name),
                     config=config,
                 )
 
@@ -88,13 +94,14 @@ class MetaModel(type):
                     name=var_name,
                     value=value,
                     annotation=annotations.get(var_name),
-                    class_validators=validators.get(var_name),
+                    class_validators=_get_validators(validators, var_name),
                     config=config,
                 )
 
         new_namespace = {
-            'config': config,
+            '__config__': config,
             '__fields__': fields,
+            '__validators__': validators,
             **{n: v for n, v in namespace.items() if n not in fields}
         }
         return super().__new__(mcs, name, bases, new_namespace)
@@ -108,6 +115,8 @@ EXTRA_ERROR = Error(Extra('extra fields not permitted'), None, None)
 class BaseModel(metaclass=MetaModel):
     # populated by the metaclass, defined here to help IDEs only
     __fields__ = {}
+    __validators__ = {}
+
     Config = BaseConfig
     __slots__ = '__values__',
 
@@ -121,11 +130,11 @@ class BaseModel(metaclass=MetaModel):
             raise AttributeError(f"'{self.__class__.__name__}' object has no attribute '{name}'")
 
     def __setattr__(self, name, value):
-        if not self.config.allow_extra and name not in self.__fields__:
+        if not self.__config__.allow_extra and name not in self.__fields__:
             raise ValueError(f'"{self.__class__.__name__}" object has no field "{name}"')
-        elif not self.config.allow_mutation:
+        elif not self.__config__.allow_mutation:
             raise TypeError(f'"{self.__class__.__name__}" is immutable and does not support item assignment')
-        elif self.config.validate_assignment:
+        elif self.__config__.validate_assignment:
             value_, error_ = self.fields[name].validate(value, self.dict(exclude={name}))
             if error_:
                 raise ValidationError({name: error_})
@@ -149,11 +158,6 @@ class BaseModel(metaclass=MetaModel):
             if k not in exclude and (not include or k in include)
         }
 
-    def values(self, **kwargs):
-        warnings.warn('.values(...) is depreciated and will be removed in future, '
-                      'it has been replaced by .dict(...)', DeprecationWarning)
-        return self.dict(**kwargs)
-
     @classmethod
     def parse_obj(cls, obj):
         if not isinstance(obj, dict):
@@ -227,14 +231,14 @@ class BaseModel(metaclass=MetaModel):
     def validate(cls, value):
         return cls(**value)
 
-    def _process_values(self, input_data: dict) -> OrderedDict:  # noqa: C901 (ignore complexity)
-        values = OrderedDict()
-        errors = OrderedDict()
+    def _process_values(self, input_data: dict) -> Dict[str, Any]:  # noqa: C901 (ignore complexity)
+        values = {}
+        errors = {}
 
         for name, field in self.__fields__.items():
             value = input_data.get(field.alias, MISSING)
             if value is MISSING:
-                if self.config.validate_all or field.validate_always:
+                if self.__config__.validate_all or field.validate_always:
                     value = field.default
                 else:
                     if field.required:
@@ -249,10 +253,10 @@ class BaseModel(metaclass=MetaModel):
             else:
                 values[name] = v_
 
-        if (not self.config.ignore_extra) or self.config.allow_extra:
+        if (not self.__config__.ignore_extra) or self.__config__.allow_extra:
             extra = input_data.keys() - {f.alias for f in self.__fields__.values()}
             if extra:
-                if self.config.allow_extra:
+                if self.__config__.allow_extra:
                     for field in extra:
                         values[field] = input_data[field]
                 else:
@@ -307,6 +311,58 @@ class BaseModel(metaclass=MetaModel):
         return self.to_string()
 
 
+def create_model(
+        model_name: str, *,
+        __config__: Type[BaseConfig]=None,
+        __base__: Type[BaseModel]=None,
+        **field_definitions):
+    """
+    Dynamically create a model.
+    :param model_name: name of the created model
+    :param __config__: config class to use for the new model
+    :param __base__: base class for the new model to inherit from
+    :param **field_definitions: fields of the model (or extra fields if a base is supplied) in the format
+        `<name>=(<type>, <default default>)` or `<name>=<default value> eg. `foobar=(str, ...)` or `foobar=123`
+    """
+    if __base__:
+        fields = deepcopy(__base__.__fields__)
+        validators = __base__.__validators__
+        if __config__ is not None:
+            raise ConfigError('to avoid confusion __config__ and __base__ cannot be used together')
+    else:
+        __base__ = BaseModel
+        fields = {}
+        validators = {}
+
+    config = __config__ or BaseConfig
+
+    for f_name, f_def in field_definitions.items():
+        if isinstance(f_def, tuple):
+            try:
+                f_annotation, f_value = f_def
+            except ValueError as e:
+                raise ConfigError(f'field definitions should either be a tuple of (<type>, <default>) or just a '
+                                  f'default value, unfortunately this means tuples as '
+                                  f'default values are not allowed') from e
+        else:
+            f_annotation, f_value = None, f_def
+        if f_name.startswith('_'):
+            warnings.warn(f'fields may not start with an underscore, ignoring "{f_name}"', RuntimeWarning)
+        else:
+            fields[f_name] = Field.infer(
+                name=f_name,
+                value=f_value,
+                annotation=f_annotation,
+                class_validators=_get_validators(validators, f_name),
+                config=config,
+            )
+    namespace = {
+        'config': config,
+        '__fields__': fields,
+    }
+    return type(model_name, (__base__,), namespace)
+
+
 _FUNCS = set()
 
 
